Reģistrācija | OiRA

Temati

# Reģistrācija

## Kāpēc man jāreģistrējas?

Pirmais, ko jums lūgs darīt, sākot savu pirmo riska novērtējumu, ir izveidot OiRA kontu — tas ir vienkāršs un ātrs process.

Reģistrēšanās sniedz jums iespēju jebkurā laikā pieteikties, lai piekļūtu saviem datiem, turpinātu iepriekšējos novērtējumus vai sāktu jaunus.

Reģistrācija nozīmē, ka OiRA sistēma var saglabāt visas jūsu sesijas un jūsu dati vienmēr būs pieejami.

Izlasiet mūsu privātuma politiku un uzziniet, kā mēs apstrādājam jūsu personas datus.

## Kāda ir atšķirība starp reģistrāciju kā lietotājam un testa sesiju?

Testa sesija ļauj ieinteresētajām personām pirms lēmuma pieņemšanas par reģistrāciju iepazīties ar rīku. Tomēr testa sesijas laikā jūsu dati netiek saglabāti un vēlāk jūs nevarēsiet izgūt nekādu informāciju, ko esat ievadījis. Testa sesijā nav iespējams izdrukāt nevienu no ziņojumiem, savukārt jūsu konta reģistrācija ļauj pilnībā dokumentēt jūsu riska novērtējumu.

## Reģistrējieties jaunam kontam

Vai šis ir jūsu pirmais apmeklējums? Sekojiet šiem vienkāršajiem soļiem, lai sāktu:

1.) Noklikšķiniet uz “Reģistrēšanās”, lai apskatītu reģistrācijas veidlapu.

Reģistrācijas veidlapa.

2.) Ievadiet savu e-pasta adresi un izvēlieties paroli (divas reizes).

3.) Noklikšķiniet uz “Tālāk”, lai reģistrētu savu jauno kontu.

4.) Izlasiet privātuma politiku un piekrītiet tai, lai turpinātu.

Tagad jūs esat pieteicies OiRA sistēmā.

## Pieteikšanās esošā kontā

Ja esat reģistrējies iepriekš, savam kontam jūs varat piekļūt šādi:

1.) Apmeklējiet pieteikšanās veidlapu. Saite uz pieteikšanās veidlapu parādīsies ikreiz, kad mēģināsiet piekļūt OiRA, kolīdz esat pieteicies sistēmā.

Pieteikšanās veidlapa.

2.) Ierakstiet savu e-pasta adresi un paroli.

3.) Piesakieties, noklikšķinot uz pogas “Ienākt”.

Kad būsiet pieteicies sistēmā, parādīsies zemāk redzamais ekrāns. No šejienes varat sākt jaunu riska novērtējumu vai atgriezties pie iepriekš sāktiem riska novērtējumiem.

Infopanelis.

Sāciet jaunu riska novērtējumu, piešķirot tam nosaukumu (piemēram, “Mans-uzņēmums 2018-07-03”), vai piekļūstiet kādam no iepriekšējiem riska novērtējumiem. Visi jūsu riska novērtējumi tiek saglabāti turpmākai zināšanai, ja vien neizvēlaties tos dzēst.

Scroll to top Load toolbar…
Back

## 1-registration.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More